==> biobb_adapters-3.6.1-py3-none-any.whl: biobb_adapters/pycompss/biobb_cmip/cmip/titration.py <==
# Python
import os
import sys
import traceback
# Pycompss
from pycompss.api.task import task
from pycompss.api.parameter import FILE_IN, FILE_OUT
# Adapters commons pycompss
from biobb_adapters.pycompss.biobb_commons import task_config
# Wrapped Biobb
from biobb_cmip.cmip.titration import Titration  # Importing class instead of module to avoid name collision

task_time_out = int(os.environ.get('TASK_TIME_OUT', 0))


@task(input_pdb_path=FILE_IN, output_pdb_path=FILE_OUT, output_log_path=FILE_OUT, input_vdw_params_path=FILE_IN, input_params_path=FILE_IN, 
      on_failure="IGNORE", time_out=task_time_out)
def _titration(input_pdb_path, output_pdb_path, output_log_path, input_vdw_params_path, input_params_path,  properties, **kwargs):
    
    task_config.pop_pmi(os.environ)
    
    try:
        Titration(input_pdb_path=input_pdb_path, output_pdb_path=output_pdb_path, output_log_path=output_log_path, input_vdw_params_path=input_vdw_params_path, input_params_path=input_params_path, properties=properties, **kwargs).launch()
    except Exception as e:
        traceback.print_exc()
        raise e
    finally:
        sys.stdout.flush()
        sys.stderr.flush()


def titration(input_pdb_path, output_pdb_path, output_log_path, input_vdw_params_path=None, input_params_path=None, properties=None, **kwargs):

    if (output_pdb_path is None or os.path.exists(output_pdb_path)) and \
       (output_log_path is None or os.path.exists(output_log_path)) and \
       True:
        print("WARN: Task Titration already executed.")
    else:
        _titration( input_pdb_path,  output_pdb_path,  output_log_path,  input_vdw_params_path,  input_params_path,  properties, **kwargs)

==> biobb_adapters-3.7.0-py3-none-any.whl: biobb_adapters/pycompss/biobb_cmip/cmip/titration.py <==
# Python
import os
import sys
import traceback
# Pycompss
from pycompss.api.task import task
from pycompss.api.parameter import FILE_IN, FILE_OUT
# Adapters commons pycompss
from biobb_adapters.pycompss.biobb_commons import task_config
# Wrapped Biobb
from biobb_cmip.cmip.titration import Titration  # Importing class instead of module to avoid name collision

task_time_out = int(os.environ.get('TASK_TIME_OUT', 0))


@task(input_pdb_path=FILE_IN, output_pdb_path=FILE_OUT, output_log_path=FILE_OUT, input_vdw_params_path=FILE_IN, input_params_path=FILE_IN, 
      on_failure="IGNORE", time_out=task_time_out)
def _titration(input_pdb_path, output_pdb_path, output_log_path, input_vdw_params_path, input_params_path,  properties, **kwargs):
    
    task_config.pop_pmi(os.environ)
    
    try:
        Titration(input_pdb_path=input_pdb_path, output_pdb_path=output_pdb_path, output_log_path=output_log_path, input_vdw_params_path=input_vdw_params_path, input_params_path=input_params_path, properties=properties, **kwargs).launch()
    except Exception as e:
        traceback.print_exc()
        raise e
    finally:
        sys.stdout.flush()
        sys.stderr.flush()


def titration(input_pdb_path, output_pdb_path, output_log_path, input_vdw_params_path=None, input_params_path=None, properties=None, **kwargs):

    if (output_pdb_path is None or (os.path.exists(output_pdb_path) and os.stat(output_pdb_path).st_size > 0)) and \
       (output_log_path is None or (os.path.exists(output_log_path) and os.stat(output_log_path).st_size > 0)) and \
       True:
        print("WARN: Task Titration already executed.")
    else:
        _titration( input_pdb_path,  output_pdb_path,  output_log_path,  input_vdw_params_path,  input_params_path,  properties, **kwargs)
